@@ -40,6 +40,8 @@ __all__ = (
     "HealthCheckTypeDef",
     "HostedZoneConfigTypeDef",
     "HostedZoneLimitTypeDef",
+    "HostedZoneOwnerTypeDef",
+    "HostedZoneSummaryTypeDef",
     "HostedZoneTypeDef",
     "LinkedServiceTypeDef",
     "QueryLoggingConfigTypeDef",
@@ -86,6 +88,7 @@ __all__ = (
     "ListGeoLocationsResponseTypeDef",
     "ListHealthChecksResponseTypeDef",
     "ListHostedZonesByNameResponseTypeDef",
+    "ListHostedZonesByVPCResponseTypeDef",
     "ListHostedZonesResponseTypeDef",
     "ListQueryLoggingConfigsResponseTypeDef",
     "ListResourceRecordSetsResponseTypeDef",
@@ -349,6 +352,15 @@ HostedZoneLimitTypeDef = TypedDict(
     {"Type": Literal["MAX_RRSETS_BY_ZONE", "MAX_VPCS_ASSOCIATED_BY_ZONE"], "Value": int},
 )
 
+HostedZoneOwnerTypeDef = TypedDict(
+    "HostedZoneOwnerTypeDef", {"OwningAccount": str, "OwningService": str}, total=False
+)
+
+HostedZoneSummaryTypeDef = TypedDict(
+    "HostedZoneSummaryTypeDef",
+    {"HostedZoneId": str, "Name": str, "Owner": "HostedZoneOwnerTypeDef"},
+)
+
 _RequiredHostedZoneTypeDef = TypedDict(
     "_RequiredHostedZoneTypeDef", {"Id": str, "Name": str, "CallerReference": str}
 )
@@ -765,6 +777,21 @@ class ListHostedZonesByNameResponseTypeDef(
     pass
 
 
+_RequiredListHostedZonesByVPCResponseTypeDef = TypedDict(
+    "_RequiredListHostedZonesByVPCResponseTypeDef",
+    {"HostedZoneSummaries": List["HostedZoneSummaryTypeDef"], "MaxItems": str},
+)
+_OptionalListHostedZonesByVPCResponseTypeDef = TypedDict(
+    "_OptionalListHostedZonesByVPCResponseTypeDef", {"NextToken": str}, total=False
+)
+
+
+class ListHostedZonesByVPCResponseTypeDef(
+    _RequiredListHostedZonesByVPCResponseTypeDef, _OptionalListHostedZonesByVPCResponseTypeDef
+):
+    pass
+
+
 _RequiredListHostedZonesResponseTypeDef = TypedDict(
     "_RequiredListHostedZonesResponseTypeDef",
     {"HostedZones": List["HostedZoneTypeDef"], "Marker": str, "IsTruncated": bool, "MaxItems": str},
